@@ -10,13 +10,12 @@ import {
   LoadingState,
   LogLevel,
   LogRowModel,
-  standardTransformersRegistry,
   toUtc,
   createDataFrame,
   ExploreLogsPanelState,
   DataQuery,
 } from '@grafana/data';
-import { organizeFieldsTransformer } from '@grafana/data/internal';
+import { mockTransformationsRegistry, organizeFieldsTransformer } from '@grafana/data/internal';
 import { config } from '@grafana/runtime';
 import { extractFieldsTransformer } from 'app/features/transformers/extractFields/extractFields';
 import { LokiQueryDirection } from 'app/plugins/datasource/loki/dataquery.gen';
@@ -66,6 +65,8 @@ describe('Logs', () => {
   let originalHref = window.location.href;
 
   beforeEach(() => {
+    window.HTMLElement.prototype.scrollIntoView = jest.fn();
+    window.HTMLElement.prototype.scroll = jest.fn();
     localStorage.clear();
     jest.clearAllMocks();
   });
@@ -74,24 +75,14 @@ describe('Logs', () => {
     Object.defineProperty(window, 'location', {
       value: {
         href: 'http://localhost:3000/explore?test',
+        search: '?test',
       },
       writable: true,
     });
   });
   beforeAll(() => {
     const transformers = [extractFieldsTransformer, organizeFieldsTransformer];
-    standardTransformersRegistry.setInit(() => {
-      return transformers.map((t) => {
-        return {
-          id: t.id,
-          aliasIds: t.aliasIds,
-          name: t.name,
-          transformation: t,
-          description: t.description,
-          editor: () => null,
-        };
-      });
-    });
+    mockTransformationsRegistry(transformers);
   });
 
   afterAll(() => {
@@ -140,9 +131,7 @@ describe('Logs', () => {
           to: toUtc('2019-01-01 16:00:00'),
           raw: { from: 'now-1h', to: 'now' },
         }}
-        addResultsToCache={() => {}}
         onChangeTime={() => {}}
-        clearCache={() => {}}
         getFieldLinks={() => {
           return [];
         }}
@@ -172,39 +161,6 @@ describe('Logs', () => {
     return { ...rendered, store: fakeStore };
   };
 
-  describe('scrolling behavior', () => {
-    let originalInnerHeight: number;
-    beforeEach(() => {
-      originalInnerHeight = window.innerHeight;
-      window.innerHeight = 1000;
-      window.HTMLElement.prototype.scrollIntoView = jest.fn();
-      window.HTMLElement.prototype.scroll = jest.fn();
-    });
-    afterEach(() => {
-      window.innerHeight = originalInnerHeight;
-    });
-
-    it('should call `scrollElement.scroll`', () => {
-      const logs = [];
-      for (let i = 0; i < 50; i++) {
-        logs.push(makeLog({ uid: `uid${i}`, rowId: `id${i}`, timeEpochMs: i }));
-      }
-      const scrollElementMock = {
-        scroll: jest.fn(),
-        scrollTop: 920,
-      };
-      setup(
-        { scrollElement: scrollElementMock as unknown as HTMLDivElement, panelState: { logs: { id: 'uid47' } } },
-        undefined,
-        logs
-      );
-
-      // element.getBoundingClientRect().top will always be 0 for jsdom
-      // calc will be `scrollElement.scrollTop - window.innerHeight / 2` -> 920 - 500 = 420
-      expect(scrollElementMock.scroll).toBeCalledWith({ behavior: 'smooth', top: 420 });
-    });
-  });
-
   it('should render logs', () => {
     setup();
     const logsSection = screen.getByTestId('logRows');
@@ -258,9 +214,7 @@ describe('Logs', () => {
             to: toUtc('2019-01-01 16:00:00'),
             raw: { from: 'now-1h', to: 'now' },
           }}
-          addResultsToCache={() => {}}
           onChangeTime={() => {}}
-          clearCache={() => {}}
           getFieldLinks={() => {
             return [];
           }}
@@ -308,9 +262,7 @@ describe('Logs', () => {
             to: toUtc('2019-01-01 16:00:00'),
             raw: { from: 'now-1h', to: 'now' },
           }}
-          addResultsToCache={() => {}}
           onChangeTime={() => {}}
-          clearCache={() => {}}
           getFieldLinks={() => {
             return [];
           }}
@@ -361,9 +313,7 @@ describe('Logs', () => {
             to: toUtc('2019-01-01 16:00:00'),
             raw: { from: 'now-1h', to: 'now' },
           }}
-          addResultsToCache={() => {}}
           onChangeTime={() => {}}
-          clearCache={() => {}}
           getFieldLinks={() => {
             return [];
           }}
@@ -424,22 +374,6 @@ describe('Logs', () => {
       expect(fakeChangePanelState).toHaveBeenCalledWith('right', 'logs', { logs: {} });
     });
 
-    it('should scroll the scrollElement into view if rows contain id', () => {
-      const panelState = { logs: { id: '3' } };
-      const scrollElementMock = { scroll: jest.fn() };
-      setup({ loading: false, scrollElement: scrollElementMock as unknown as HTMLDivElement, panelState });
-
-      expect(scrollElementMock.scroll).toHaveBeenCalled();
-    });
-
-    it('should not scroll the scrollElement into view if rows does not contain id', () => {
-      const panelState = { logs: { id: 'not-included' } };
-      const scrollElementMock = { scroll: jest.fn() };
-      setup({ loading: false, scrollElement: scrollElementMock as unknown as HTMLDivElement, panelState });
-
-      expect(scrollElementMock.scroll).not.toHaveBeenCalled();
-    });
-
     it('should call reportInteraction on permalinkClick', async () => {
       const panelState = { logs: { id: 'not-included' } };
       const rows = [
@@ -491,8 +425,6 @@ describe('Logs', () => {
     });
 
     it('should call createAndCopyShortLink on permalinkClick - with infinite scrolling', async () => {
-      const featureToggleValue = config.featureToggles.logsInfiniteScrolling;
-      config.featureToggles.logsInfiniteScrolling = true;
       const rows = [
         makeLog({ uid: '1', rowId: 'id1', timeEpochMs: 1 }),
         makeLog({ uid: '2', rowId: 'id2', timeEpochMs: 1 }),
@@ -515,7 +447,6 @@ describe('Logs', () => {
         )
       );
       expect(createAndCopyShortLink).toHaveBeenCalledWith(expect.stringMatching('visualisationType%22:%22logs'));
-      config.featureToggles.logsInfiniteScrolling = featureToggleValue;
     });
   });
 
